//
//Necessary steady state values from baseline
//

 %   #Y_ss = 2.54635648817299; 
 %   #R_ss = 1.01010101010101;
 %   #Rk_ss = 1.01260101010101;
 %   #Pi_ss = 1;
    
//
//Epidemiological block (SIR)
//

//1. Subceptible dynamics
    //[mcp='S>0']
    //S = S(-1) - alphav*Itilde(-1)*S(-1);

//2. Infected dynamics
    //[mcp='Itilde<1']
    //Itilde = Itilde(-1) + alphav*Itilde(-1)*S(-1) - gammav*Itilde(-1);

//3. Recovered dynamics
    //[mcp='Rtilde<1']
    //Rtilde = Rtilde(-1) + gammav*Itilde(-1);

//4. Labor supply
L = 1 - Itilde;


//
//Households
//

//5. Marginal utility of consumption
lambda_c = 1/(C-h*C(-1)) - betta*h/(C(+1)-h*C);

//6. Euler equation
    //R(+1)*Lambda(+1) = 1;
(1+i)/Pi(+1)*Lambda(+1) = 1;

//7. Stochastic discount rate
    //Lambda(+1)  =   betta*lambda_c(+1)/lambda_c;
Lambda  =   betta*lambda_c/lambda_c(-1);


//
//Private banks
//

//8. Value of banks' capital
nu = Lambda(+1)*Gamma(+1)*(Rk(+1)-R(+1));

//9. Value of banks' net wealth
eta = Lambda(+1)*Gamma(+1)*R(+1);

//10. Auxiliar variable
Gamma = 1 - theta + theta*lambda*phi;

//11. Optimal leverage
phi = eta/(lambda - nu);

//12. Banks' net worth
Omega = theta*((Rk-R)*phi(-1) + R)*Omega(-1) + epsilon*Q*Z(-1);

//12b. Expected discounted terminal wealth
V = nu*Q*Z + eta*Omega;

//12c. Expected discounted value of banks' capital
Q_Z = Q*Z;

//12d. Expected discounted value of banks' capital
V1 = nu*Q*Z;

//12e. Expected discounted value of banks' net wealth
V2 = eta*Omega;


//
//Corona Bonds
//

//13. Aggregate capital
Q*Z = phi/(1-psi)*Omega;


//
//Intermediate physical goods
//

//14. Assets and capital
Q*K(+1) = Q*Z;

//15. Production function
Ym = (K)^alfa*L^(1-alfa);

//16. Wage equilibrium
W = (1-alfa)*Pm*Ym/L;

//17. Return on capital
Rk = (alfa*Pm*Ym/K + (1-delta)*Q)/Q(-1);


//
//Capital Producers
//

//18. Capital accumulation
K(+1) = (1-delta)*K + In;

//19. Optimal investment decision
Q =   1+ f + fprime*In/In(-1) - Lambda(+1)*fprime(+1)*(In(+1)/In)^2;

//20-21. Auxiliars variables
f = kappa/2*(In/In(-1)-1)^2;
fprime = kappa*(In/In(-1) - 1);


//
//Retailers
//

//22. Aggregation final goods
Ym = vp*Y;

//23. Price dispersion
vp = theta_p*(Pi(-1)^chi)^(-epsilon_p)*vp(-1) + (1-theta_p)*Pistar^(-epsilon_p);

//24. Price dynamics
1 = theta_p*(Pi(-1)^chi/Pi)^(1-epsilon_p) + (1-theta_p)*Pistar^(1-epsilon_p);

//25. Optimal price
g1 = epsilon_p/(epsilon_p-1)*g2;

//26-27. Auxiliars variables 
g1 = lambda_c*Ym*Pistar + betta*theta_p*Pistar/Pistar(+1)*(Pi^chi/Pi(+1))^(1-epsilon_p)*g1(+1);
g2 = lambda_c*Ym*Pm + betta*theta_p*(Pi^chi/Pi(+1))^(-epsilon_p)*g2(+1);


//
//Government and Central Bank
//

//28. Unemployment benefits
b = zetta*W;

//29. Unconventional Monetary Policy
psi = psi_bar + omega*(log(Rk(+1)) - log(R(+1)) - (log(steady_state(Rk))-log(steady_state(R))));

//30. Interest Rate Rule
1+i = (1+i(-1))^phi_i*(1/betta* (Pi/steady_state(Pi))^phi_pi * (Y/steady_state(Y))^phi_y)^(1-phi_i);

//31. Fisher equation
    //1+i = R(+1)*Pi(+1);
1+i(-1) = R*Pi;

//
//Equilibrium 
//

//32. Aggregate resource constraint
Y = C + In + f*In + G + tau*psi*Q*K(+1);

//33. Government consumption
G = omega_g*steady_state(Y);
